@@ -1,6 +1,5 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
 """Use this as a copy-and-paste template for your own scripts.
 """
 
@@ -40,7 +39,14 @@ def callout(master, args):
 ap = ArgumentParser(description="pyXCP skeleton.", callout=callout)
 
 # Add command-line option for seed-and-key DLL.
-ap.parser.add_argument("-s", "--sk-dll", dest="sk_dll", help="Seed-and-Key .DLL name", type=str, default=None)
+ap.parser.add_argument(
+    "-s",
+    "--sk-dll",
+    dest="sk_dll",
+    help="Seed-and-Key .DLL name",
+    type=str,
+    default=None,
+)
 
 with ap.run() as x:
     x.connect()
