@@ -111,7 +111,9 @@ def timecode(ticks, mode):
 
 
 def cstest():
-    tr = transport.Eth("localhost", port=5555, protocol="UDP", loglevel="WARN")  # "DEBUG"
+    tr = transport.Eth(
+        "localhost", port=5555, protocol="UDP", loglevel="WARN"
+    )  # "DEBUG"
     # tr = transport.SxI("COM27", 115200, loglevel = "WARN")
     with Master(tr) as xm:
         #    tm = Timing()
@@ -236,7 +238,7 @@ def bench(xm):
     result = OrderedDict()
     for pn in range(8, 257, 8):
         # for pn in range(8, 257, 32):
-        result[pn] = list()
+        result[pn] = []
         for i in range(10):
             gid = xm.getID(0x4)
             start = time.perf_counter()
