@@ -1,6 +1,5 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
 """Implements error-handling according to XCP spec.
 """
 
@@ -39,7 +38,8 @@ from pyxcp.types import XcpResponseError, XcpTimeoutError, XcpError, COMMAND_CAT
 from pyxcp.errormatrix import ERROR_MATRIX, PreAction, Action
 from ..logger import Logger
 
-handle_errors = True # enable/disable XCP error-handling.
+handle_errors = True  # enable/disable XCP error-handling.
+
 
 class SingletonBase(object):
     _lock = threading.Lock()
@@ -97,10 +97,16 @@ def getActions(service, error_code):
         eh = getErrorHandler(service)
         if eh is None:
             raise InternalError("Invalid Service 0x{:02x}".format(service))
-        print("Try to handle error -- Service: {} Error-Code: {}".format(service.name, error_code))
+        print(
+            "Try to handle error -- Service: {} Error-Code: {}".format(
+                service.name, error_code
+            )
+        )
         handler = eh.get(error_str)
         if handler is None:
-            raise UnhandledError("Service '{}' has no handler for '{}'.".format(service.name, error_code))
+            raise UnhandledError(
+                "Service '{}' has no handler for '{}'.".format(service.name, error_code)
+            )
         preActions, actions = handler
     return preActions, actions
 
@@ -136,7 +142,9 @@ class Arguments:
         self.kwargs = kwargs
 
     def __str__(self):
-        res = "{}(ARGS = {}, KWS = {})".format(self.__class__.__name__, self.args, self.kwargs)
+        res = "{}(ARGS = {}, KWS = {})".format(
+            self.__class__.__name__, self.args, self.kwargs
+        )
         return res
 
     def __eq__(self, other):
@@ -199,7 +207,9 @@ class Handler:
     def __init__(self, instance, func, arguments, error_code=None):
         self.instance = instance
         if hasattr(func, "__closure__") and func.__closure__:
-            self.func = func.__closure__[0].cell_contents  # Use original, undecorated function to prevent
+            self.func = func.__closure__[
+                0
+            ].cell_contents  # Use original, undecorated function to prevent
             # nasty recursion problems.
         else:
             self.func = func
@@ -213,14 +223,24 @@ class Handler:
         )
 
     def __eq__(self, other):
-        return (self.instance == other.instance) and (self.func == other.func) and (self.arguments == other.arguments)
+        return (
+            (self.instance == other.instance)
+            and (self.func == other.func)
+            and (self.arguments == other.arguments)
+        )
 
     def execute(self):
-        self.logger.debug("EXECUTE func = {} arguments = {})".format(func_name(self.func), self.arguments))
+        self.logger.debug(
+            "EXECUTE func = {} arguments = {})".format(
+                func_name(self.func), self.arguments
+            )
+        )
         if isinstance(self.func, types.MethodType):
             return self.func(*self.arguments.args, **self.arguments.kwargs)
         else:
-            return self.func(self.instance, *self.arguments.args, **self.arguments.kwargs)
+            return self.func(
+                self.instance, *self.arguments.args, **self.arguments.kwargs
+            )
 
     def actions(self, preActions, actions):
         """Preprocess errorhandling pre-actions and actions."""
@@ -241,7 +261,9 @@ class Handler:
                 fn = Function(self.instance.setMta, Arguments(self.instance.mta))
                 result_pre_actions.append(fn)
             elif item == PreAction.SET_DAQ_PTR:
-                fn = Function(self.instance.setDaqPtr, Arguments(self.instance.currentDaqPtr))
+                fn = Function(
+                    self.instance.setDaqPtr, Arguments(self.instance.currentDaqPtr)
+                )
             elif item == PreAction.START_STOP_X:
                 raise NotImplementedError("START_STOP_X")
             elif item == PreAction.REINIT_DAQ:
@@ -269,7 +291,9 @@ class Handler:
             elif item == Action.USE_A2L:
                 raise UnhandledError("Could not proceed due to unhandled error.")
             elif item == Action.USE_ALTERATIVE:
-                raise UnhandledError("Could not proceed due to unhandled error.")  # TODO: check alternatives.
+                raise UnhandledError(
+                    "Could not proceed due to unhandled error."
+                )  # TODO: check alternatives.
             elif item == Action.REPEAT:
                 repetitionCount = Repeater.REPEAT
             elif item == Action.REPEAT_2_TIMES:
@@ -356,7 +380,9 @@ class Executor(SingletonBase):
                 if self.newHandler:
                     self.error_code = XcpError.ERR_TIMEOUT
             except Exception as e:
-                raise UnrecoverableError("Don't know how to handle exception '{}'".format(repr(e))) from e
+                raise UnrecoverableError(
+                    "Don't know how to handle exception '{}'".format(repr(e))
+                ) from e
             else:
                 self.error_code = None
                 # print("\t\t\t*** SUCCESS ***")
@@ -365,7 +391,9 @@ class Executor(SingletonBase):
                     # print("OK, all handlers passed: '{}'.".format(res))
                     return res
             if self.error_code != None:
-                preActions, actions, repeater = handler.actions(*getActions(inst.service, self.error_code))
+                preActions, actions, repeater = handler.actions(
+                    *getActions(inst.service, self.error_code)
+                )
                 self.repeater = repeater
                 for f, a in reversed(preActions):
                     self.handlerStack.push(Handler(inst, f, a, self.error_code))
