@@ -1,16 +1,14 @@
 import pytest
 
-from pyxcp.transport.can import (
-    setDLC,
-    calculateFilter,
-    CAN_EXTENDED_ID,
-    isExtendedIdentifier,
-    stripIdentifier,
-    Identifier,
-    MAX_11_BIT_IDENTIFIER,
-    MAX_29_BIT_IDENTIFIER,
-    IdentifierOutOfRangeError,
-)
+from pyxcp.transport.can import calculateFilter
+from pyxcp.transport.can import CAN_EXTENDED_ID
+from pyxcp.transport.can import Identifier
+from pyxcp.transport.can import IdentifierOutOfRangeError
+from pyxcp.transport.can import isExtendedIdentifier
+from pyxcp.transport.can import MAX_11_BIT_IDENTIFIER
+from pyxcp.transport.can import MAX_29_BIT_IDENTIFIER
+from pyxcp.transport.can import setDLC
+from pyxcp.transport.can import stripIdentifier
 
 
 def testSet0():
@@ -96,7 +94,10 @@ def testfilter1():
 
 
 def testfilter2():
-    assert calculateFilter([0x101, 0x102 | CAN_EXTENDED_ID, 0x103]) == (0x100, 0x1FFFFFFC)
+    assert calculateFilter([0x101, 0x102 | CAN_EXTENDED_ID, 0x103]) == (
+        0x100,
+        0x1FFFFFFC,
+    )
 
 
 def testfilter3():
@@ -130,7 +131,18 @@ def testfilter4():
 
 
 def testfilter5():
-    assert calculateFilter([0x1560 | CAN_EXTENDED_ID, 0x1561, 0x1562, 0x1563, 0x1564, 0x1565, 0x1566, 0x1567]) == (
+    assert calculateFilter(
+        [
+            0x1560 | CAN_EXTENDED_ID,
+            0x1561,
+            0x1562,
+            0x1563,
+            0x1564,
+            0x1565,
+            0x1566,
+            0x1567,
+        ]
+    ) == (
         0x1560,
         0x1FFFFFF8,
     )
