@@ -1,6 +1,10 @@
 from sys import version_info
 
-from pyxcp.utils import hexDump, slicer, flatten, getPythonVersion, PYTHON_VERSION
+from pyxcp.utils import flatten
+from pyxcp.utils import getPythonVersion
+from pyxcp.utils import hexDump
+from pyxcp.utils import PYTHON_VERSION
+from pyxcp.utils import slicer
 
 
 def test_hexdump(capsys):
