@@ -37,7 +37,10 @@ class Timing:
         T_MS: "mS",
         T_S: "S",
     }
-    FMT = "min:  {0:2.3f} {4}\nmax:  {1:2.3f} {4}\n" "avg:  {2:2.3f} {4}\nlast: {3:2.3f} {4}"
+    FMT = (
+        "min:  {0:2.3f} {4}\nmax:  {1:2.3f} {4}\n"
+        "avg:  {2:2.3f} {4}\nlast: {3:2.3f} {4}"
+    )
 
     def __init__(self, unit=T_MS, record=False):
         self.min = None
@@ -71,7 +74,11 @@ class Timing:
         self.avg = 0 if self.avg is None else self.avg
         self._previous = 0 if self._previous is None else self._previous
         return Timing.FMT.format(
-            self.min * self.unit, self.max * self.unit, self.avg * self.unit, self._previous * self.unit, unitName
+            self.min * self.unit,
+            self.max * self.unit,
+            self.avg * self.unit,
+            self._previous * self.unit,
+            unitName,
         )
 
     __repr__ = __str__
